You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2016/05/22 01:05:22 UTC

svn commit: r1745006 [8/9] - in /openoffice/trunk/main: ./ accessibility/inc/accessibility/standard/ autodoc/inc/ary/idl/ avmedia/source/framework/ basctl/source/basicide/ basctl/source/inc/ basegfx/inc/basegfx/color/ basegfx/inc/basegfx/polygon/ baseg...

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/OutputRepository.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/OutputRepository.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/OutputRepository.java (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/OutputRepository.java Sun May 22 01:05:14 2016
@@ -48,7 +48,7 @@ public interface OutputRepository
      */
     OutputStream createOutputStream(final String name, final String mimeType) throws IOException;
 
-    /** allows to acces sub repositories inside this repository
+    /** allows to access sub repositories inside this repository
      * 
      * @param name describes the path to the sub repository
      * @param mimeType

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/SOFormulaParser.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/SOFormulaParser.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/SOFormulaParser.java (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/SOFormulaParser.java Sun May 22 01:05:14 2016
@@ -220,7 +220,7 @@ public final class SOFormulaParser exten
             catch (ParseException ex)
             {
                 boolean found = false;
-                // error occured so all token must be bad
+                // error occurred so all token must be bad
                 for (int i = 0; i < tokens.size(); i++)
                 {
                     if (!found && ex.currentToken != null && images.get(i).equals(ex.currentToken.image))

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/StarReportModule.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/StarReportModule.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/StarReportModule.java (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/StarReportModule.java Sun May 22 01:05:14 2016
@@ -43,7 +43,7 @@ public class StarReportModule extends Ab
      *
      * @param subSystem the subSystem.
      * @throws org.jfree.base.modules.ModuleInitializeException
-     *          if an error ocurred while initializing the module.
+     *          if an error occurred while initializing the module.
      */
     public void initialize(final SubSystem subSystem)
             throws ModuleInitializeException

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/loader/InputRepositoryLoader.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/loader/InputRepositoryLoader.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/loader/InputRepositoryLoader.java (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/loader/InputRepositoryLoader.java Sun May 22 01:05:14 2016
@@ -109,7 +109,7 @@ public class InputRepositoryLoader imple
     {
         if (!isSupportedKey(parent))
         {
-            throw new ResourceKeyCreationException("Assertation: Unsupported parent key type");
+            throw new ResourceKeyCreationException("Assertion: Unsupported parent key type");
         }
 
         final InputResourceKey parentKey = (InputResourceKey) parent.getIdentifier();

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/model/FormattedTextElement.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/model/FormattedTextElement.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/model/FormattedTextElement.java (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/model/FormattedTextElement.java Sun May 22 01:05:14 2016
@@ -26,7 +26,7 @@ import org.jfree.report.expressions.Form
 
 /**
  * A formatted text element takes a formula, evaluates it and formats the
- * given element using some arbitary style. (As this is totally undocumented,
+ * given element using some arbitrary style. (As this is totally undocumented,
  * we leave this out for now. Either we'll insert a field there or we call
  * an UNO-component to do the formatting.
  *

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/model/ReportElement.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/model/ReportElement.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/model/ReportElement.java (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/model/ReportElement.java Sun May 22 01:05:14 2016
@@ -71,7 +71,7 @@ public abstract class ReportElement exte
      * element will only be printed, if there was at least one change.
      *
      * @return true, if repeated values should be printed, false if repeated
-     *         values should be surpressed.
+     *         values should be suppressed.
      */
     public boolean isPrintRepeatedValues()
     {

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/module.properties
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/module.properties?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/module.properties (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/module.properties Sun May 22 01:05:14 2016
@@ -25,7 +25,7 @@ module-info:
   name: factory-report-sun
   producer: The JFreeReport project - www.jfree.org/jfreereport
   description: XML-Parsers for OpenOffice.org report definitions. These definitions\
-    are basicly similiar to the old JFreeReport format, with some limited absolute\
+    are basically similar to the old JFreeReport format, with some limited absolute\
     positioning capabilities.
   version.major: 0
   version.minor: 90

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/output/OfficeDocumentReportTarget.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/output/OfficeDocumentReportTarget.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/output/OfficeDocumentReportTarget.java (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/output/OfficeDocumentReportTarget.java Sun May 22 01:05:14 2016
@@ -146,7 +146,7 @@ public abstract class OfficeDocumentRepo
     public static final String FAILED = "Failed";
     public static final String VERTICAL_POS = "vertical-pos";
     private static final String ZERO_CM = "0cm";
-    /** the verison of the ODF specification to which generated documents
+    /** the version of the ODF specification to which generated documents
      *  shall conform. */
     public static final String ODF_VERSION = "1.2";
 
@@ -345,7 +345,7 @@ public abstract class OfficeDocumentRepo
      *
      * @param report the report object.
      * @throws DataSourceException       if there was an error accessing the datasource
-     * @throws ReportProcessingException if some other error occured.
+     * @throws ReportProcessingException if some other error occurred.
      */
     public void startReport(final ReportStructureRoot report)
             throws DataSourceException, ReportProcessingException
@@ -509,7 +509,7 @@ public abstract class OfficeDocumentRepo
     }
 
     /**
-     * Starts the processing of an element and updates the processing state. This will select an apropriate handler method
+     * Starts the processing of an element and updates the processing state. This will select an appropriate handler method
      * for the call and will call one of the start* methods.
      *
      * @param roAttrs the attribute map for the current element

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/output/text/TextRawReportTarget.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/output/text/TextRawReportTarget.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/output/text/TextRawReportTarget.java (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/output/text/TextRawReportTarget.java Sun May 22 01:05:14 2016
@@ -220,7 +220,7 @@ public class TextRawReportTarget extends
     {
         // create the master page for the report-header.
         // If there is a page-header or footer in the report that gets
-        // surpressed on the report-header, we have to insert a pagebreak
+        // suppressed on the report-header, we have to insert a pagebreak
         // afterwards.
 
         final String activePageFooter;
@@ -429,7 +429,7 @@ public class TextRawReportTarget extends
      * @throws org.jfree.report.DataSourceException
      *          if there was an error accessing the datasource
      * @throws org.jfree.report.ReportProcessingException
-     *          if some other error occured.
+     *          if some other error occurred.
      */
     public void startReport(final ReportStructureRoot report)
             throws DataSourceException, ReportProcessingException

Modified: openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/parser/table/TableCellReadHandler.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/parser/table/TableCellReadHandler.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/parser/table/TableCellReadHandler.java (original)
+++ openoffice/trunk/main/reportbuilder/java/com/sun/star/report/pentaho/parser/table/TableCellReadHandler.java Sun May 22 01:05:14 2016
@@ -26,7 +26,7 @@ import com.sun.star.report.pentaho.model
 import com.sun.star.report.pentaho.parser.text.NoCDATATextContentReadHandler;
 
 /**
- * A read handler for table-cell contents. This is basicly a text-content
+ * A read handler for table-cell contents. This is basically a text-content
  * read handler; we may extend this implementation later.
  *
  * @author Thomas Morgner

Modified: openoffice/trunk/main/reportdesign/inc/RptDef.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/inc/RptDef.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/inc/RptDef.hxx (original)
+++ openoffice/trunk/main/reportdesign/inc/RptDef.hxx Sun May 22 01:05:14 2016
@@ -84,7 +84,7 @@ public:
 		return lhs;
 	}
 };
-/** returns teh object type depending on the service name
+/** returns the object type depending on the service name
 	@param	_xComponent the report component
 */
 REPORTDESIGN_DLLPUBLIC sal_uInt16 getObjectType(const ::com::sun::star::uno::Reference< ::com::sun::star::report::XReportComponent>& _xComponent);

Modified: openoffice/trunk/main/reportdesign/qa/complex/reportdesign/ReportDesignerTest.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/qa/complex/reportdesign/ReportDesignerTest.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/qa/complex/reportdesign/ReportDesignerTest.java (original)
+++ openoffice/trunk/main/reportdesign/qa/complex/reportdesign/ReportDesignerTest.java Sun May 22 01:05:14 2016
@@ -618,7 +618,7 @@ public class ReportDesignerTest
             catch (com.sun.star.util.CloseVetoException e)
             {
                 System.out.println("ERROR: CloseVetoException caught");
-                System.out.println("CloseVetoException occured Can't close document.");
+                System.out.println("CloseVetoException occurred Can't close document.");
                 System.out.println("Message: " + e.getMessage());
             }
         }

Modified: openoffice/trunk/main/reportdesign/source/core/api/ReportDefinition.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/core/api/ReportDefinition.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/source/core/api/ReportDefinition.cxx (original)
+++ openoffice/trunk/main/reportdesign/source/core/api/ReportDefinition.cxx Sun May 22 01:05:14 2016
@@ -1901,7 +1901,7 @@ void SAL_CALL OReportDefinition::load( c
         {
             if ( i == nLastOpenMode )
                 throw lang::WrappedTargetException(
-                    ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "An error occured while creating the document storage." ) ),
+                    ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "An error occurred while creating the document storage." ) ),
                         // TODO: resource
                     *this,
                     ::cppu::getCaughtException()

Modified: openoffice/trunk/main/reportdesign/source/core/inc/Section.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/core/inc/Section.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/source/core/inc/Section.hxx (original)
+++ openoffice/trunk/main/reportdesign/source/core/inc/Section.hxx Sun May 22 01:05:14 2016
@@ -89,7 +89,7 @@ namespace reportdesign
 			l.notify();
 		}
 
-        /** checks if this section is eiter the page header or footer and if so it throws an UnknownPropertyException
+        /** checks if this section is either the page header or footer and if so it throws an UnknownPropertyException
         *
         */
         void checkNotPageHeaderFooter();

Modified: openoffice/trunk/main/reportdesign/source/core/misc/conditionalexpression.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/core/misc/conditionalexpression.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/source/filter/xml/xmlfilter.cxx (original)
+++ openoffice/trunk/main/reportdesign/source/filter/xml/xmlfilter.cxx Sun May 22 01:05:14 2016
@@ -243,7 +243,7 @@ sal_Int32 ReadThroughComponent(
 			if ( !xStorage->hasByName( sStreamName ) || !xStorage->isStreamElement( sStreamName ) )
 			{
 				// stream name not found! Then try the compatibility name.
-				// if no stream can be opened, return immediatly with OK signal
+				// if no stream can be opened, return immediately with OK signal
 		
 				// do we even have an alternative name?
 				if ( NULL == pCompatibilityStreamName )
@@ -655,7 +655,7 @@ sal_Bool ORptFilter::implImport( const S
 						// TODO/LATER: no way to transport the error outside from the filter!
 						break;
 					}
-					// fall through intented
+					// fall through intended
 				default:
 					{
             			// TODO/LATER: this is completely wrong! Filter code should never call ErrorHandler directly! But for now this is the only way!

Modified: openoffice/trunk/main/reportdesign/source/ui/inc/GeometryHandler.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/ui/inc/GeometryHandler.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/source/ui/inc/GeometryHandler.hxx (original)
+++ openoffice/trunk/main/reportdesign/source/ui/inc/GeometryHandler.hxx Sun May 22 01:05:14 2016
@@ -149,13 +149,13 @@ namespace rptui
         */
         bool impl_isDataField(const ::rtl::OUString& _sName) const;
 
-        /**return all formula in a semicolon seperated list
+        /**return all formula in a semicolon separated list
         *
         * \param _rList the localized function names
         */
         void impl_fillFormulaList_nothrow(::std::vector< ::rtl::OUString >& _out_rList) const;
 
-        /** return all group names in a semicolon seperated list starting with the group where this control is contained in.
+        /** return all group names in a semicolon separated list starting with the group where this control is contained in.
         *
         * \param _rList fills the list with all scope names.
         */
@@ -190,7 +190,7 @@ namespace rptui
         *
         * \param _sQuotedFunction the quoted function name
         * \param _Out_rDataField the data field which is used in the function
-        * \param _xFunctionsSupplier teh function supplier to search or empty if not used
+        * \param _xFunctionsSupplier the function supplier to search or empty if not used
         * \param _bSet If set to sal_True than the m_sDefaultFunction and m_sScope vars will be set if successful.
         * \return sal_True with known otherwise sal_False
         */
@@ -210,7 +210,7 @@ namespace rptui
                                             ,::rtl::OUString& _rDataField
                                             ,::rtl::OUString& _rsDefaultFunctionName) const;
 
-        /** fills the memeber m_aDefaultFunctions
+        /** fills the member m_aDefaultFunctions
         *
         */
         void loadDefaultFunctions();

Modified: openoffice/trunk/main/reportdesign/source/ui/inc/ReportController.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/ui/inc/ReportController.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/source/ui/inc/ReportController.hxx (original)
+++ openoffice/trunk/main/reportdesign/source/ui/inc/ReportController.hxx Sun May 22 01:05:14 2016
@@ -267,7 +267,7 @@ namespace rptui
 
         /** gets the current section (SdrView)
         *
-        * \return the currently selected section or <NULL/> if noone is selected
+        * \return the currently selected section or <NULL/> if no one is selected
         */
         OSectionView* getCurrentSectionView() const;
 

Modified: openoffice/trunk/main/reportdesign/source/ui/inspection/DataProviderHandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/ui/inspection/DataProviderHandler.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/source/ui/inspection/DataProviderHandler.cxx (original)
+++ openoffice/trunk/main/reportdesign/source/ui/inspection/DataProviderHandler.cxx Sun May 22 01:05:14 2016
@@ -190,7 +190,7 @@ uno::Any SAL_CALL DataProviderHandler::g
     switch(nId)
     {
         case PROPERTY_ID_CHARTTYPE:
-            // TODO: We need a possiblity to get the UI of the selected chart type
+            // TODO: We need a possibility to get the UI of the selected chart type
             //if( m_xChartModel.is() )
             //{
             //    uno::Reference< chart2::XDiagram > xDiagram( m_xChartModel->getFirstDiagram() );

Modified: openoffice/trunk/main/reportdesign/source/ui/report/ViewsWindow.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/ui/report/ViewsWindow.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/source/ui/report/ViewsWindow.cxx (original)
+++ openoffice/trunk/main/reportdesign/source/ui/report/ViewsWindow.cxx Sun May 22 01:05:14 2016
@@ -1108,7 +1108,7 @@ void OViewsWindow::BegDragObj(const Poin
     // Create drag lines over all viewable Views
 	// Therefore we need to identify the marked objects
 	// and create temporary objects on all other views at the same position
-	// relative to its occurance.
+	// relative to its occurrence.
 
     OSL_TRACE("BegDragObj createInvisible Objects\n" );
     int nViewCount = 0;
@@ -1331,7 +1331,7 @@ void OViewsWindow::EndDragObj(sal_Bool _
     {
         EndDragObj_removeInvisibleObjects();
 
-		// we need to manipulate the current clickpoint, we substract the old delta from BeginDrag
+		// we need to manipulate the current clickpoint, we subtract the old delta from BeginDrag
         // OSectionView* pInSection = getSectionRelativeToPosition(_pSection, aPnt);
         // aNewPos.X() -= m_aDragDelta.X();
         // aNewPos.Y() -= m_aDragDelta.Y();

Modified: openoffice/trunk/main/reportdesign/source/ui/report/propbrw.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/ui/report/propbrw.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/reportdesign/source/ui/report/propbrw.cxx (original)
+++ openoffice/trunk/main/reportdesign/source/ui/report/propbrw.cxx Sun May 22 01:05:14 2016
@@ -572,7 +572,7 @@ void PropBrw::Update( OSectionView* pNew
     }
     catch ( Exception& )
     {
-        DBG_ERROR( "PropBrw::Update: Exception occured!" );
+        DBG_ERROR( "PropBrw::Update: Exception occurred!" );
     }
 }
 //----------------------------------------------------------------------------
@@ -594,7 +594,7 @@ void PropBrw::Update( const uno::Referen
 	    }
 	    catch ( Exception& )
         {
-            DBG_ERROR( "PropBrw::Update: Exception occured!" );
+            DBG_ERROR( "PropBrw::Update: Exception occurred!" );
         }
     }
 }

Modified: openoffice/trunk/main/sal/inc/osl/security_decl.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/inc/osl/security_decl.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sal/inc/osl/security_decl.hxx (original)
+++ openoffice/trunk/main/sal/inc/osl/security_decl.hxx Sun May 22 01:05:14 2016
@@ -71,28 +71,28 @@ public:
 	/** get the ident of the logged in user.
 		@param strName [out] is the buffer which returns the name
 		@param max [in] is the size of this buffer
-		@return True, if any user is successfuly logged in, otherwise False
+		@return True, if any user is successfully logged in, otherwise False
 	*/
     inline sal_Bool  SAL_CALL getUserIdent( ::rtl::OUString& strIdent) const;
 
 	/** get the name of the logged in user.
 		@param strName [out] is the buffer which returns the name
 		@param max [in] is the size of this buffer
-		@return True, if any user is successfuly logged in, otherwise False
+		@return True, if any user is successfully logged in, otherwise False
 	*/
     inline sal_Bool SAL_CALL getUserName( ::rtl::OUString& strName) const;
 
 	/** get the home directory of the logged in user.
 		@param strDirectory [out] is the buffer which returns the directory name
 		@param max [in] is the size of this buffer
-		@return True, if any user is successfuly logged in, otherwise False
+		@return True, if any user is successfully logged in, otherwise False
 	*/
     inline sal_Bool SAL_CALL getHomeDir( ::rtl::OUString& strDirectory) const;
 
 	/** get the directory for configuration data of the logged in user.
 		@param strDirectory [out] is the buffer which returns the directory name
 		@param max [in] is the size of this buffer
-		@return True, if any user is successfuly logged in, otherwise False
+		@return True, if any user is successfully logged in, otherwise False
 	*/
     inline sal_Bool SAL_CALL getConfigDir( ::rtl::OUString & strDirectory) const;
 

Modified: openoffice/trunk/main/sal/osl/w32/file_url.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/osl/w32/file_url.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sal/osl/w32/file_url.cxx (original)
+++ openoffice/trunk/main/sal/osl/w32/file_url.cxx Sun May 22 01:05:14 2016
@@ -1013,7 +1013,7 @@ oslFileError SAL_CALL osl_searchFileURL(
 			dwResult = SearchPath( lpszSearchPath, lpszSearchFile, NULL, nBufferLength, lpBuffer, &lpszFilePart ); 
 		} while ( dwResult && dwResult >= nBufferLength );
 
-		/*	... until an error occures or buffer is large enough. 
+		/*	... until an error occurs or buffer is large enough. 
 			dwResult == nBufferLength can not happen according to documentation but lets be robust ;-) */
 
 		if ( dwResult )

Modified: openoffice/trunk/main/sal/qa/osl/mutex/osl_Mutex.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/mutex/osl_Mutex.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/mutex/osl_Mutex.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/mutex/osl_Mutex.cxx Sun May 22 01:05:14 2016
@@ -490,7 +490,7 @@ namespace osl_Mutex
 		if ( bRes2 == sal_True )
 			aMutex.release( );
 
-		ASSERT_TRUE(bRes1 == sal_False && bRes2 == sal_True && bRunning == sal_True) << "release Mutex: try to aquire before and after the mutex has been released";
+		ASSERT_TRUE(bRes1 == sal_False && bRes2 == sal_True && bRunning == sal_True) << "release Mutex: try to acquire before and after the mutex has been released";
 
 	}
 
@@ -503,7 +503,7 @@ namespace osl_Mutex
 		sal_Bool bRes1 = aMutex.release( );
 		sal_Bool bRes2 = aMutex.release( );
 	
-		ASSERT_TRUE(bRes1 == sal_False && bRes2 == sal_False) << "release Mutex: mutex should not be released without aquire, should not release twice. although the behaviour is still under discussion, this test is passed on (LINUX), not passed on (SOLARIS)&(WINDOWS)";
+		ASSERT_TRUE(bRes1 == sal_False && bRes2 == sal_False) << "release Mutex: mutex should not be released without acquire, should not release twice. although the behaviour is still under discussion, this test is passed on (LINUX), not passed on (SOLARIS)&(WINDOWS)";
 #endif
 	}
 	
@@ -625,7 +625,7 @@ namespace osl_Guard
 		aMutex.release( );
 		myThread.join( );
 
-		ASSERT_TRUE(bRes == sal_True) << "GuardThread constructor: reference initialization, aquire the mutex before running the thread, then check if it is blocking.";
+		ASSERT_TRUE(bRes == sal_True) << "GuardThread constructor: reference initialization, acquire the mutex before running the thread, then check if it is blocking.";
 	}
 	
 } // namespace osl_Guard
@@ -682,7 +682,7 @@ namespace osl_ClearableGuard
 		/// it will return sal_False if the aMutex has not been Guarded.
 		sal_Bool bRes = aMutex.release( );
 
-		ASSERT_TRUE(bRes == sal_True) << "ClearableMutexGuard constructor, test the aquire operation when initilized.";
+		ASSERT_TRUE(bRes == sal_True) << "ClearableMutexGuard constructor, test the acquire operation when initilized.";
 	}
 
 	TEST_F(ClearableGuardConstructor, ctor_002 )
@@ -695,7 +695,7 @@ namespace osl_ClearableGuard
 		/// it will return sal_False if the aMutex has not been Guarded.
 		sal_Bool bRes = aMutex.release( );
 
-		ASSERT_TRUE(bRes == sal_True) << "ClearableMutexGuard constructor, test the aquire operation when initilized, we use reference constructor this time.";
+		ASSERT_TRUE(bRes == sal_True) << "ClearableMutexGuard constructor, test the acquire operation when initilized, we use reference constructor this time.";
 	}
 	
 	class clear : public ::testing::Test
@@ -806,7 +806,7 @@ namespace osl_ResettableGuard
 		/// it will return sal_False if the aMutex has not been Guarded.
 		sal_Bool bRes = aMutex.release( );
 
-		ASSERT_TRUE(bRes == sal_True) << "ResettableMutexGuard constructor, test the aquire operation when initilized.";
+		ASSERT_TRUE(bRes == sal_True) << "ResettableMutexGuard constructor, test the acquire operation when initilized.";
 	}
 
 	TEST_F(ctor, ctor_002 )
@@ -819,7 +819,7 @@ namespace osl_ResettableGuard
 		/// it will return sal_False if the aMutex has not been Guarded.
 		sal_Bool bRes = aMutex.release( );
 
-		ASSERT_TRUE(bRes == sal_True) << "ResettableMutexGuard constructor, test the aquire operation when initilized, we use reference constructor this time.";
+		ASSERT_TRUE(bRes == sal_True) << "ResettableMutexGuard constructor, test the acquire operation when initilized, we use reference constructor this time.";
 	}
 
 	
@@ -863,7 +863,7 @@ namespace osl_ResettableGuard
 		myMutexGuard.reset( );
 		sal_Bool bRes1 = aMutex.release( );
 		
-		ASSERT_TRUE(( sal_False == bRes ) && ( sal_True == bRes1 )) << "ResettableMutexGuard method: reset, release after clear and reset, on Solaris, the mutex can be release without aquire, so it can not passed on (SOLARIS), but not the reason for reset_002";
+		ASSERT_TRUE(( sal_False == bRes ) && ( sal_True == bRes1 )) << "ResettableMutexGuard method: reset, release after clear and reset, on Solaris, the mutex can be release without acquire, so it can not passed on (SOLARIS), but not the reason for reset_002";
 #endif
 	}
 	

Modified: openoffice/trunk/main/sal/qa/osl/process/osl_Thread.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/process/osl_Thread.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/process/osl_Thread.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/process/osl_Thread.cxx Sun May 22 01:05:14 2016
@@ -580,7 +580,7 @@ namespace osl_Thread
             myThread* newthread = new myThread();
             sal_Bool res1 = newthread->create();
             sal_Bool res2 = newthread->create();
-            printf("In non pro, an assertion should occured. This behaviour is right.\n");
+            printf("In non pro, an assertion should occurred. This behaviour is right.\n");
             termAndJoinThread(newthread);
             delete newthread;
 

Modified: openoffice/trunk/main/sal/qa/osl/socket/osl_Socket.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/socket/osl_Socket.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/socket/osl_Socket.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/socket/osl_Socket.cxx Sun May 22 01:05:14 2016
@@ -824,7 +824,7 @@ namespace osl_SocketAddr
 
         ASSERT_TRUE(saSocketAddr.is( ) == sal_True &&
                                 ( saSocketAddr.getPort( ) == IP_PORT_FTP )/*&&
-                                ( sal_True == compareUString( saSocketAddr.getHostname( ), aHostName1 ) ) */) << "test for SocketAddr tcpip specif constructor function: do a constructor using tcpip spec, check the result.";
+                                ( sal_True == compareUString( saSocketAddr.getHostname( ), aHostName1 ) ) */) << "test for SocketAddr tcpip specific constructor function: do a constructor using tcpip spec, check the result.";
     }
 
     //same as is_002
@@ -833,7 +833,7 @@ namespace osl_SocketAddr
         /// tcpip-specif constructor.
         ::osl::SocketAddr saSocketAddr( aHostIpInval1, IP_PORT_MYPORT2 );
 
-        ASSERT_TRUE(sal_False == saSocketAddr.is( )) << "test for SocketAddr tcpip specif constructor function: using an invalid IP address, the socketaddr ctors should fail";
+        ASSERT_TRUE(sal_False == saSocketAddr.is( )) << "test for SocketAddr tcpip specific constructor function: using an invalid IP address, the socketaddr ctors should fail";
     }
 
 	/** testing the method:

Modified: openoffice/trunk/main/sal/qa/osl/socket/osl_SocketAddr.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sal/qa/osl/socket/osl_SocketAddr.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sal/qa/osl/socket/osl_SocketAddr.cxx (original)
+++ openoffice/trunk/main/sal/qa/osl/socket/osl_SocketAddr.cxx Sun May 22 01:05:14 2016
@@ -198,7 +198,7 @@ namespace osl_SocketAddr
 
         ASSERT_TRUE(saSocketAddr.is( ) == sal_True &&
                                 ( saSocketAddr.getPort( ) == IP_PORT_FTP )/*&&
-                                ( sal_True == compareUString( saSocketAddr.getHostname( ), aHostName1 ) ) */) << "test for SocketAddr tcpip specif constructor function: do a constructor using tcpip spec, check the result.";
+                                ( sal_True == compareUString( saSocketAddr.getHostname( ), aHostName1 ) ) */) << "test for SocketAddr tcpip specific constructor function: do a constructor using tcpip spec, check the result.";
     }
 
     //same as is_002
@@ -207,7 +207,7 @@ namespace osl_SocketAddr
         /// tcpip-specif constructor.
         ::osl::SocketAddr saSocketAddr( rtl::OUString::createFromAscii("123.345.67.89"), IP_PORT_MYPORT2 );
 
-        ASSERT_TRUE(sal_False == saSocketAddr.is( )) << "test for SocketAddr tcpip specif constructor function: using an invalid IP address, the socketaddr ctors should fail";
+        ASSERT_TRUE(sal_False == saSocketAddr.is( )) << "test for SocketAddr tcpip specific constructor function: using an invalid IP address, the socketaddr ctors should fail";
     }
 
 

Modified: openoffice/trunk/main/sc/inc/compressedarray.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/inc/compressedarray.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/inc/compressedarray.hxx (original)
+++ openoffice/trunk/main/sc/inc/compressedarray.hxx Sun May 22 01:05:14 2016
@@ -434,7 +434,7 @@ public:
 
 // === ScBitMaskCompressedArray ==============================================
 
-/** The data type represents bits, managable by bitwise operations.
+/** The data type represents bits, manageable by bitwise operations.
  */
 
 template< typename A, typename D > class ScBitMaskCompressedArray : public ScCompressedArray<A,D>

Modified: openoffice/trunk/main/sc/inc/document.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/inc/document.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/inc/document.hxx (original)
+++ openoffice/trunk/main/sc/inc/document.hxx Sun May 22 01:05:14 2016
@@ -1432,7 +1432,7 @@ public:
     SCROW           GetNextDifferentChangedRow( SCTAB nTab, SCROW nStart, bool bCareManualSize = true) const;
 
     // returns whether to export a Default style for this col/row or not
-	// nDefault is setted to one position in the current row/col where the Default style is
+	// nDefault is set to one position in the current row/col where the Default style is
 	sal_Bool			GetColDefault( SCTAB nTab, SCCOL nCol, SCROW nLastRow, SCROW& nDefault);
 	sal_Bool			GetRowDefault( SCTAB nTab, SCROW nRow, SCCOL nLastCol, SCCOL& nDefault);
 

Modified: openoffice/trunk/main/sc/qa/complex/cellRanges/CheckXCellRangesQuery.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/qa/complex/cellRanges/CheckXCellRangesQuery.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/qa/complex/cellRanges/CheckXCellRangesQuery.java (original)
+++ openoffice/trunk/main/sc/qa/complex/cellRanges/CheckXCellRangesQuery.java Sun May 22 01:05:14 2016
@@ -83,7 +83,7 @@ public class CheckXCellRangesQuery /* ex
             System.out.println( "creating a Spreadsheet document" );
             m_xSheetDoc = SOF.createCalcDoc(null);
         } catch ( com.sun.star.uno.Exception e ) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(  );
             fail( "Couldn?t create document");
         }

Modified: openoffice/trunk/main/sc/qa/complex/dataPilot/CheckDataPilot.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/qa/complex/dataPilot/CheckDataPilot.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/qa/complex/dataPilot/CheckDataPilot.java (original)
+++ openoffice/trunk/main/sc/qa/complex/dataPilot/CheckDataPilot.java Sun May 22 01:05:14 2016
@@ -195,7 +195,7 @@ public class CheckDataPilot {
             System.out.println( "Creating a Spreadsheet document" );
             xSheetDoc = SOF.createCalcDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace();
             throw new StatusException( "Couldn't create document", e );
         }

Modified: openoffice/trunk/main/sc/qa/complex/sc/CalcRTL.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/qa/complex/sc/CalcRTL.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/qa/complex/sc/CalcRTL.java (original)
+++ openoffice/trunk/main/sc/qa/complex/sc/CalcRTL.java Sun May 22 01:05:14 2016
@@ -232,7 +232,7 @@ public class CalcRTL /* extends ComplexT
             System.out.println("creating a sheetdocument");
             xSheetDoc = SOF.createCalcDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             worked = false;
             e.printStackTrace(/*(PrintWriter) log*/ System.out);
         }

Modified: openoffice/trunk/main/sc/source/core/data/column2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/source/core/data/column2.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/source/core/data/column2.cxx (original)
+++ openoffice/trunk/main/sc/source/core/data/column2.cxx Sun May 22 01:05:14 2016
@@ -442,7 +442,7 @@ long ScColumn::GetNeededSize( SCROW nRow
 			SfxItemSet* pSet = new SfxItemSet( pEngine->GetEmptyItemSet() );
 			pPattern->FillEditItemSet( pSet, pCondSet );
 
-//			no longer needed, are setted with the text (is faster)
+//			no longer needed, are set with the text (is faster)
 //			pEngine->SetDefaults( pSet );
 
 			if ( ((const SfxBoolItem&)pSet->Get(EE_PARA_HYPHENATE)).GetValue() ) {

Modified: openoffice/trunk/main/sc/source/core/data/tabprotection.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/source/core/data/tabprotection.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/source/core/data/tabprotection.cxx (original)
+++ openoffice/trunk/main/sc/source/core/data/tabprotection.cxx Sun May 22 01:05:14 2016
@@ -194,7 +194,7 @@ bool ScTableProtectionImpl::hasPasswordH
 Sequence<sal_Int8> ScTableProtectionImpl::getPasswordHash(ScPasswordHash eHash) const
 {
     if (mbEmptyPass)
-        // Flaged as empty.
+        // Flagged as empty.
         return Sequence<sal_Int8>();
 
     if (maPassText.Len())

Modified: openoffice/trunk/main/sc/source/filter/excel/xetable.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/source/filter/excel/xetable.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/source/filter/excel/xetable.cxx (original)
+++ openoffice/trunk/main/sc/source/filter/excel/xetable.cxx Sun May 22 01:05:14 2016
@@ -1877,7 +1877,7 @@ void XclExpRow::Finalize( const ScfUInt1
 
     // *** Fill gaps with BLANK/MULBLANK cell records *** ---------------------
 
-    /*  This is needed because nonexistant cells in Calc are not formatted at all,
+    /*  This is needed because nonexistent cells in Calc are not formatted at all,
         but in Excel they would have the column default format. Blank cells that
         are equal to the respective column default are removed later in this function. */
     if( !mbAlwaysEmpty )

Modified: openoffice/trunk/main/sc/source/filter/xml/xmlexprt.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/source/filter/xml/xmlexprt.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/source/filter/xml/xmlexprt.cxx (original)
+++ openoffice/trunk/main/sc/source/filter/xml/xmlexprt.cxx Sun May 22 01:05:14 2016
@@ -1643,7 +1643,7 @@ void ScXMLExport::_ExportContent()
 		sal_Int32 nShapesCount(0);
 		sal_Int32 nCellCount(pDoc ? pDoc->GetCellCount() : 0);
 		CollectSharedData(nTableCount, nShapesCount, nCellCount);
-		DBG_ERROR("no shared data setted");
+		DBG_ERROR("no shared data set");
 	}
 	ScXMLExportDatabaseRanges aExportDatabaseRanges(*this);
     if (!GetModel().is())
@@ -1864,7 +1864,7 @@ void ScXMLExport::_ExportStyles( sal_Boo
 		sal_Int32 nShapesCount(0);
 		sal_Int32 nCellCount(pDoc ? pDoc->GetCellCount() : 0);
 		CollectSharedData(nTableCount, nShapesCount, nCellCount);
-		//DBG_ERROR("no shared data setted");
+		//DBG_ERROR("no shared data set");
 	}
 	ScXMLStyleExport aStylesExp(*this, rtl::OUString(), GetAutoStylePool().get());
 	if (GetModel().is())
@@ -2445,7 +2445,7 @@ void ScXMLExport::_ExportAutoStyles()
             sal_Int32 nShapesCount(0);
             sal_Int32 nCellCount(pDoc ? pDoc->GetCellCount() : 0);
             CollectSharedData(nTableCount, nShapesCount, nCellCount);
-            //DBG_ERROR("no shared data setted");
+            //DBG_ERROR("no shared data set");
         }
         sal_Int32 nTableCount(xIndex->getCount());
         pCellStyles->AddNewTable(nTableCount - 1);

Modified: openoffice/trunk/main/sc/source/ui/vba/vbarange.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sc/source/ui/vba/vbarange.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sc/source/ui/vba/vbarange.cxx (original)
+++ openoffice/trunk/main/sc/source/ui/vba/vbarange.cxx Sun May 22 01:05:14 2016
@@ -3966,7 +3966,7 @@ ScVbaRange::setRowHeight( const uno::Any
 		}
 		return;
 	}
-	double nHeight = 0; // Incomming height is in points
+	double nHeight = 0; // Incoming height is in points
         _rowheight >>= nHeight;
 	nHeight = lcl_Round2DecPlaces( nHeight );
 	RangeHelper thisRange( mxRange );	

Modified: openoffice/trunk/main/scp2/macros/macro.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/scp2/macros/macro.pl?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/scp2/macros/macro.pl (original)
+++ openoffice/trunk/main/scp2/macros/macro.pl Sun May 22 01:05:14 2016
@@ -265,7 +265,7 @@ sub startup_check
     usage() if $i<2;
     usage() if "$outfile" eq "";
     if ( -f "$outfile" ) {
-		# changed script - run allways
+		# changed script - run always
 		return if (stat($0))[9] > (stat("$outfile"))[9] ;
 
         open OLDFILE, "$outfile" or die "$0 - ERROR: $outfile exists but isn't readable.\n";

Modified: openoffice/trunk/main/scripting/source/provider/MasterScriptProvider.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/scripting/source/provider/MasterScriptProvider.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/scripting/source/provider/MasterScriptProvider.cxx (original)
+++ openoffice/trunk/main/scripting/source/provider/MasterScriptProvider.cxx Sun May 22 01:05:14 2016
@@ -207,7 +207,7 @@ throw ( Exception, RuntimeException )
     }
     else // no args
     {
-        // use either scriping context or maybe zero args?
+        // use either scripting context or maybe zero args?
         invokeArgs = Sequence< Any >( 0 ); // no arguments
     }
     m_sAargs = invokeArgs;

Modified: openoffice/trunk/main/scripting/source/stringresource/stringresource.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/scripting/source/stringresource/stringresource.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/scripting/source/stringresource/stringresource.cxx (original)
+++ openoffice/trunk/main/scripting/source/stringresource/stringresource.cxx Sun May 22 01:05:14 2016
@@ -688,7 +688,7 @@ LocaleItem* StringResourceImpl::getItemF
 }
 
 // Returns the LocalItem for a given locale, if it exists, otherwise NULL
-// This method performes a closest match search, at least the language must match
+// This method performs a closest match search, at least the language must match
 LocaleItem* StringResourceImpl::getClosestMatchItemForLocale( const Locale& locale )
 {
 	LocaleItem* pRetItem = NULL;

Modified: openoffice/trunk/main/scripting/source/stringresource/stringresource.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/scripting/source/stringresource/stringresource.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/scripting/source/stringresource/stringresource.hxx (original)
+++ openoffice/trunk/main/scripting/source/stringresource/stringresource.hxx Sun May 22 01:05:14 2016
@@ -160,7 +160,7 @@ protected:
 		throw (::com::sun::star::lang::IllegalArgumentException);
 
 	// Returns the LocalItem for a given locale, if it exists, otherwise NULL
-	// This method performes a closest match search, at least the language must match
+	// This method performs a closest match search, at least the language must match
 	LocaleItem* getClosestMatchItemForLocale( const ::com::sun::star::lang::Locale& locale );
 	void implSetCurrentLocale( const ::com::sun::star::lang::Locale& locale,
 		sal_Bool FindClosestMatch, sal_Bool bUseDefaultIfNoMatch )

Modified: openoffice/trunk/main/sd/source/core/drawdoc2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/core/drawdoc2.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/core/drawdoc2.cxx (original)
+++ openoffice/trunk/main/sd/source/core/drawdoc2.cxx Sun May 22 01:05:14 2016
@@ -1545,7 +1545,7 @@ sal_uInt16 SdDrawDocument::InsertPageSet
     String aNotesPageName = sNotesPageName;
 
     // Gather some information about the standard page and the notes page
-    // that are to be inserted.  This makes sure that there is allways one
+    // that are to be inserted.  This makes sure that there is always one
     // standard page followed by one notes page.
     if (ePageKind == PK_NOTES)
     {

Modified: openoffice/trunk/main/sd/source/filter/xml/sdxmlwrp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/filter/xml/sdxmlwrp.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/filter/xml/sdxmlwrp.cxx (original)
+++ openoffice/trunk/main/sd/source/filter/xml/sdxmlwrp.cxx Sun May 22 01:05:14 2016
@@ -723,7 +723,7 @@ sal_Bool SdXMLFilter::Import( ErrCode& n
             nError = ERRCODE_IO_BROKENPACKAGE;
 			break;
 		}
-		// fall through intented
+		// fall through intended
 	default:
 		{
             // TODO/LATER: this is completely wrong! Filter code should never call ErrorHandler directly!

Modified: openoffice/trunk/main/sd/source/ui/accessibility/AccessibleViewForwarder.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/accessibility/AccessibleViewForwarder.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/accessibility/AccessibleViewForwarder.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/accessibility/AccessibleViewForwarder.cxx Sun May 22 01:05:14 2016
@@ -33,7 +33,7 @@
 
 namespace accessibility {
 
-/** For the time beeing, the implementation of this class will not use the
+/** For the time being, the implementation of this class will not use the
     member mrDevice.  Instead the device is retrieved from the view
     every time it is used.  This is necessary because the device has to stay
     up-to-date with the current view and the class has to stay compatible.

Modified: openoffice/trunk/main/sd/source/ui/app/sdmod2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/app/sdmod2.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/app/sdmod2.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/app/sdmod2.cxx Sun May 22 01:05:14 2016
@@ -133,7 +133,7 @@ static SdPage* GetCurrentPage( sd::ViewS
 		// which all use the new possibility of setting the visualized page at the SdrOutliner.
 
 		// if all else failed, geht the current page from the object that is
-		// currently formated from the document
+		// currently formatted from the document
 		if(!pPage)
 		{
 			const SdrTextObj* pTextObj = (pViewSh && pViewSh->GetDoc()) ? pViewSh->GetDoc()->GetFormattingTextObj() : NULL;

Modified: openoffice/trunk/main/sd/source/ui/func/futext.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/func/futext.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/func/futext.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/func/futext.cxx Sun May 22 01:05:14 2016
@@ -900,7 +900,7 @@ sal_Bool FuText::MouseButtonUp(const Mou
 
 					// #107235#
 					// Analog to the else case below, for vertical simple click texts
-					// one of the defaulted setted items from ImpSetAttributesForNewTextObject
+					// one of the defaulted set items from ImpSetAttributesForNewTextObject
 					// needs to be adapted to non-block mode. This could have been done with the
 					// #104122#, but was obviously overseen.
 					const SfxItemSet& rSet = mpView->GetDefaultAttr();

Modified: openoffice/trunk/main/sd/source/ui/inc/AccessibleDrawDocumentView.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/inc/AccessibleDrawDocumentView.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/inc/AccessibleDrawDocumentView.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/inc/AccessibleDrawDocumentView.hxx Sun May 22 01:05:14 2016
@@ -134,7 +134,7 @@ protected:
         index has the special value ACCESSIBLE_SELECTION_CHILD_ALL.
         Selecting or deselecting a child sets or resets the
         <const>SELECTED</const> state and selects or deslects the UNO shape
-        beeing made accessible by the child.
+        being made accessible by the child.
         @param nAccessibleChildIndex
             Index of the child to select or deselect.  If the parameter has
             the value ACCESSIBLE_SELECTION_CHILD_ALL then all children are

Modified: openoffice/trunk/main/sd/source/ui/inc/AccessibleSlideSorterObject.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/inc/AccessibleSlideSorterObject.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/inc/AccessibleSlideSorterObject.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/inc/AccessibleSlideSorterObject.hxx Sun May 22 01:05:14 2016
@@ -222,7 +222,7 @@ private:
     sal_uInt32 mnClientId;
 
     /** Check whether or not the object has been disposed (or is in the
-        state of beeing disposed).  If that is the case then
+        state of being disposed).  If that is the case then
         DisposedException is thrown to inform the (indirect) caller of the
         foul deed.
     */
@@ -230,7 +230,7 @@ private:
         throw (::com::sun::star::lang::DisposedException);
 
     /** Check whether or not the object has been disposed (or is in the
-        state of beeing disposed). 
+        state of being disposed). 
 
         @return sal_True, if the object is disposed or in the course
         of being disposed. Otherwise, sal_False is returned.

Modified: openoffice/trunk/main/sd/source/ui/inc/AccessibleSlideSorterView.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/inc/AccessibleSlideSorterView.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/inc/AccessibleSlideSorterView.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/inc/AccessibleSlideSorterView.hxx Sun May 22 01:05:14 2016
@@ -301,7 +301,7 @@ private:
     ::Window* mpContentWindow;
 
     /** Check whether or not the object has been disposed (or is in the
-        state of beeing disposed).  If that is the case then
+        state of being disposed).  If that is the case then
         DisposedException is thrown to inform the (indirect) caller of the
         foul deed.
     */
@@ -309,7 +309,7 @@ private:
         throw (::com::sun::star::lang::DisposedException);
 
     /** Check whether or not the object has been disposed (or is in the
-        state of beeing disposed). 
+        state of being disposed). 
 
         @return sal_True, if the object is disposed or in the course
         of being disposed. Otherwise, sal_False is returned.

Modified: openoffice/trunk/main/sd/source/ui/inc/AccessibleTreeNode.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/inc/AccessibleTreeNode.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/inc/AccessibleTreeNode.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/inc/AccessibleTreeNode.hxx Sun May 22 01:05:14 2016
@@ -248,7 +248,7 @@ protected:
     virtual ~AccessibleTreeNode (void);
 
     /** Check whether or not the object has been disposed (or is in the
-        state of beeing disposed).  If that is the case then
+        state of being disposed).  If that is the case then
         DisposedException is thrown to inform the (indirect) caller of the
         foul deed.
     */
@@ -256,7 +256,7 @@ protected:
         throw (::com::sun::star::lang::DisposedException);
 
     /** Check whether or not the object has been disposed (or is in the
-        state of beeing disposed). 
+        state of being disposed). 
 
         @return sal_True, if the object is disposed or in the course
         of being disposed. Otherwise, sal_False is returned.

Modified: openoffice/trunk/main/sd/source/ui/inc/GraphicViewShell.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/inc/GraphicViewShell.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/inc/GraphicViewShell.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/inc/GraphicViewShell.hxx Sun May 22 01:05:14 2016
@@ -63,7 +63,7 @@ public:
 
 	virtual ~GraphicViewShell (void);
 
-    /** This method is overloaded in order to have the layer mode allways
+    /** This method is overloaded in order to have the layer mode always
         active.
     */
 	virtual void ChangeEditMode (EditMode eMode, bool bIsLayerModeActive);

Modified: openoffice/trunk/main/sd/source/ui/inc/ViewShell.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/inc/ViewShell.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/inc/ViewShell.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/inc/ViewShell.hxx Sun May 22 01:05:14 2016
@@ -85,7 +85,7 @@ class ZoomList;
 
     <p>Despite its name this class is not a descendant of SfxViewShell
     but of SfxShell.  Its name expresses the fact that it acts like a
-    view shell.  Beeing a stacked shell rather then being an actual view shell
+    view shell.  Being a stacked shell rather then being an actual view shell
     there can be several instances of this class that
     <ul>
     <li>all are based on the same view shell and thus show the same

Modified: openoffice/trunk/main/sd/source/ui/inc/taskpane/TitledControl.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/inc/taskpane/TitledControl.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/inc/taskpane/TitledControl.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/inc/taskpane/TitledControl.hxx Sun May 22 01:05:14 2016
@@ -65,7 +65,7 @@ public:
             The typical action of the click handler is to expand the control.
         @param eType
             Type of the title bar.  This specifies how the title bar
-            will be formated.  For more information see TitleBar.
+            will be formatted.  For more information see TitleBar.
             
     */
     TitledControl (

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/controller/SlsSelectionFunction.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/controller/SlsSelectionFunction.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/controller/SlsSelectionFunction.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/controller/SlsSelectionFunction.cxx Sun May 22 01:05:14 2016
@@ -1357,7 +1357,7 @@ bool NormalModeHandler::ProcessButtonDow
 
         case BUTTON_DOWN | LEFT_BUTTON | DOUBLE_CLICK | OVER_SELECTED_PAGE:
         case BUTTON_DOWN | LEFT_BUTTON | DOUBLE_CLICK | OVER_UNSELECTED_PAGE:
-            // A double click allways shows the selected slide in the center
+            // A double click always shows the selected slide in the center
             // pane in an edit view.
             SetCurrentPage(rDescriptor.mpHitDescriptor);
             SwitchView(rDescriptor.mpHitDescriptor);

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/inc/cache/SlsCacheContext.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/cache/SlsCacheContext.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/cache/SlsCacheContext.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/cache/SlsCacheContext.hxx Sun May 22 01:05:14 2016
@@ -88,7 +88,7 @@ public:
 
     /** Return the model to which the pages belong for which the called
         cache manages the previews.  Different caches that belong to the
-        same model but have different preview sizes may acces previews of
+        same model but have different preview sizes may access previews of
         each other in order to create fast previews of the previews.
     */
     virtual ::com::sun::star::uno::Reference<com::sun::star::uno::XInterface> GetModel (void) = 0;

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/inc/cache/SlsPageCacheManager.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/cache/SlsPageCacheManager.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/cache/SlsPageCacheManager.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/cache/SlsPageCacheManager.hxx Sun May 22 01:05:14 2016
@@ -105,7 +105,7 @@ public:
 
     /** Invalidate the preview bitmaps for all slides that belong to the
         specified document.  This is necessary after model changes that
-        affect e.g. page number fiels.
+        affect e.g. page number fields.
     */
     void InvalidateAllPreviewBitmaps (DocumentKey pDocument);
 

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsPageSelector.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsPageSelector.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsPageSelector.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/inc/controller/SlsPageSelector.hxx Sun May 22 01:05:14 2016
@@ -57,7 +57,7 @@ class SlideSorterController;
     has to be done explicitly by calling the
     CurrentSlideManager::SetCurrentSlide() method.
 
-    Indices of pages relate allways to the number of all pages in the model
+    Indices of pages relate always to the number of all pages in the model
     (as returned by GetPageCount()) not just the selected pages.
 */
 class PageSelector : private ::boost::noncopyable

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/shell/SlideSorter.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/shell/SlideSorter.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/shell/SlideSorter.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/shell/SlideSorter.cxx Sun May 22 01:05:14 2016
@@ -542,7 +542,7 @@ bool SlideSorter::RelocateToWindow (::Wi
 
     // For accessibility we have to shortly hide the content window.  This
     // triggers the construction of a new accessibility object for the new
-    // view shell.  (One is created earlier while the construtor of the base
+    // view shell.  (One is created earlier while the constructor of the base
     // class is executed.  But because at that time the correct
     // accessibility object can not be constructed we do that now.)
     if (mpContentWindow.get() !=NULL)

Modified: openoffice/trunk/main/sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx Sun May 22 01:05:14 2016
@@ -197,7 +197,7 @@ void SlideSorterViewShell::Initialize (v
 
     // For accessibility we have to shortly hide the content window.
     // This triggers the construction of a new accessibility object for
-    // the new view shell.  (One is created earlier while the construtor
+    // the new view shell.  (One is created earlier while the constructor
     // of the base class is executed.  At that time the correct
     // accessibility object can not be constructed.)
     SharedSdWindow pWindow (mpSlideSorter->GetContentWindow());

Modified: openoffice/trunk/main/sd/source/ui/unoidl/unolayer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/unoidl/unolayer.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/unoidl/unolayer.hxx (original)
+++ openoffice/trunk/main/sd/source/ui/unoidl/unolayer.hxx Sun May 22 01:05:14 2016
@@ -89,7 +89,7 @@ public:
     virtual void SAL_CALL addEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& xListener ) throw (::com::sun::star::uno::RuntimeException);
     virtual void SAL_CALL removeEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& aListener ) throw (::com::sun::star::uno::RuntimeException);
 
-    /** Not implemented.  Allways throws an exception.
+    /** Not implemented.  Always throws an exception.
         @raises NoSupportException.
     */
     virtual void SAL_CALL setParent( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Parent ) throw (::com::sun::star::lang::NoSupportException, ::com::sun::star::uno::RuntimeException);

Modified: openoffice/trunk/main/sd/source/ui/view/drviewsa.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/drviewsa.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/drviewsa.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/drviewsa.cxx Sun May 22 01:05:14 2016
@@ -765,7 +765,7 @@ void DrawViewShell::GetStatusBarState(Sf
 	// Display of current page and layer.
 	if( SFX_ITEM_AVAILABLE == rSet.GetItemState( SID_STATUS_PAGE ) )
 	{
-        // Allways show the slide/page number.
+        // Always show the slide/page number.
 		String aString (SdResId( STR_SD_PAGE ));
         aString += sal_Unicode(' ');
         aString += UniString::CreateFromInt32( maTabControl.GetCurPageId() );

Modified: openoffice/trunk/main/sd/source/ui/view/grviewsh.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/grviewsh.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/grviewsh.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/grviewsh.cxx Sun May 22 01:05:14 2016
@@ -84,7 +84,7 @@ void GraphicViewShell::ChangeEditMode (
     bool )
 {
     // There is no page tab that could be shown instead of the layer tab.
-    // Therefore we have it allways visible regardless of what the caller
+    // Therefore we have it always visible regardless of what the caller
     // said. (We have to change the callers behaviour, of course.)
     DrawViewShell::ChangeEditMode (eMode, true);
 }

Modified: openoffice/trunk/main/sd/source/ui/view/sdwindow.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sd/source/ui/view/sdwindow.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sd/source/ui/view/sdwindow.cxx (original)
+++ openoffice/trunk/main/sd/source/ui/view/sdwindow.cxx Sun May 22 01:05:14 2016
@@ -925,7 +925,7 @@ void Window::DataChanged( const DataChan
 			 (rDCEvt.GetFlags() & SETTINGS_STYLE) )
 		{
             // When the screen zoom factor has changed then reset the zoom
-            // factor of the frame to allways display the whole page.
+            // factor of the frame to always display the whole page.
             const AllSettings* pOldSettings = rDCEvt.GetOldSettings ();
             const AllSettings& rNewSettings = GetSettings ();
             if (pOldSettings)

Modified: openoffice/trunk/main/set_soenv.in
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/set_soenv.in?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/set_soenv.in (original)
+++ openoffice/trunk/main/set_soenv.in Sun May 22 01:05:14 2016
@@ -24,7 +24,7 @@
 #---------------------------------------------------------------------------
 # Description:
 # set_soenv generates a file that contains all necessary 
-# environment variables for the build proces of OpenOffice
+# environment variables for the build process of OpenOffice
 # on Linux, NetBSD, Solaris, Windows NT and Mac OS X/Darwin.
 #
 # Program steps.
@@ -954,7 +954,7 @@ if ($platform =~ m/cygwin/)
    {
       $JAVA_LIB             = $JAVA_HOME.$LIB;
    }
-   # Import SystemDrive enviroment variable
+   # Import SystemDrive environment variable
    use Env qw(SYSTEMDRIVE);
    # Change $SYSTEMDRIVE to lower case.
    $SYSTEMDRIVE          = lc $SYSTEMDRIVE;
@@ -1493,7 +1493,7 @@ elsif ($platform =~ m/darwin/)
     $GUIBASE  = "aqua";
 }
 else
-{  AddWarning( "set_soenv", "$platform not configured for system dependant include dir" );
+{  AddWarning( "set_soenv", "$platform not configured for system dependent include dir" );
 }
 
 #
@@ -2533,7 +2533,7 @@ sub WinFormat
 
 #----------------------------------------------------------
 # Function name: WinPath
-# Description:   Reformat a $sep seperated path using DOS paths.
+# Description:   Reformat a $sep separated path using DOS paths.
 # Arguments:     1. Variable (string)
 #                2. Separaror (string)
 # Return value:  Reformatted String

Modified: openoffice/trunk/main/sfx2/inc/sfx2/docfile.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/inc/sfx2/docfile.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/inc/sfx2/docfile.hxx (original)
+++ openoffice/trunk/main/sfx2/inc/sfx2/docfile.hxx Sun May 22 01:05:14 2016
@@ -317,7 +317,7 @@ public:
 
 	SAL_DLLPRIVATE sal_Bool SignContents_Impl( sal_Bool bScriptingContent, const ::rtl::OUString& aODFVersion, sal_Bool bHasValidDocumentSignature );
 
-	// the following two methods must be used and make sence only during saving currently
+	// the following two methods must be used and make sense only during saving currently
 	// TODO/LATER: in future the signature state should be controlled by the medium not by the document
 	//             in this case the methods will be used generally, and might need to be renamed
 	SAL_DLLPRIVATE sal_uInt16 GetCachedSignatureState_Impl();

Modified: openoffice/trunk/main/sfx2/inc/sfx2/filedlghelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/inc/sfx2/filedlghelper.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/inc/sfx2/filedlghelper.hxx (original)
+++ openoffice/trunk/main/sfx2/inc/sfx2/filedlghelper.hxx Sun May 22 01:05:14 2016
@@ -265,7 +265,7 @@ public:
     // XDialogClosedListener methods
     virtual void SAL_CALL   DialogClosed( const ::com::sun::star::ui::dialogs::DialogClosedEvent& _rEvent );
 
-	// retrieves the top-most file picker - i.e. the instance which is currently beeing executed
+	// retrieves the top-most file picker - i.e. the instance which is currently being executed
 	static ::com::sun::star::uno::Reference< ::com::sun::star::ui::dialogs::XFilePicker >
 							GetTopMostFilePicker( );
 

Modified: openoffice/trunk/main/sfx2/inc/sfx2/styfitem.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/inc/sfx2/styfitem.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/inc/sfx2/styfitem.hxx (original)
+++ openoffice/trunk/main/sfx2/inc/sfx2/styfitem.hxx Sun May 22 01:05:14 2016
@@ -102,7 +102,7 @@ public:
 
 	/** updates the images of all single SfxStyleFamilyItems with new images from the given resource
 
-		<p>The resource must contain a local image lists, with the id beeing the integer equivalent for the
+		<p>The resource must contain a local image lists, with the id being the integer equivalent for the
 		requested bitmap mode, incremented by 1.</p>
 
 		<p>Usually, you will use the same resource which originally constructed the object.</p>

Modified: openoffice/trunk/main/sfx2/source/appl/appopen.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/appl/appopen.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/appl/appopen.cxx (original)
+++ openoffice/trunk/main/sfx2/source/appl/appopen.cxx Sun May 22 01:05:14 2016
@@ -267,7 +267,7 @@ private:
     try
     {
         // check the encryption data
-        // if the data correct is the stream will be opened successfuly
+        // if the data correct is the stream will be opened successfully
         // and immediately closed
         ::comphelper::OStorageHelper::SetCommonStorageEncryptionData( mxStorage, rEncryptionData );
 

Modified: openoffice/trunk/main/sfx2/source/bastyp/bitset.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/bastyp/bitset.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/bastyp/bitset.cxx (original)
+++ openoffice/trunk/main/sfx2/source/bastyp/bitset.cxx Sun May 22 01:05:14 2016
@@ -172,7 +172,7 @@ BitSet::BitSet( sal_uInt16* pArray, sal_
 	}
 	else
 	{
-		// initalize emtpy set
+		// initialize emtpy set
 		nBlocks = 0;
 		pBitmap = 0;
 	}

Modified: openoffice/trunk/main/sfx2/source/bastyp/fltfnc.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/bastyp/fltfnc.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/bastyp/fltfnc.cxx (original)
+++ openoffice/trunk/main/sfx2/source/bastyp/fltfnc.cxx Sun May 22 01:05:14 2016
@@ -878,7 +878,7 @@ const SfxFilter* SfxFilterMatcherIter::N
 }
 
 /*---------------------------------------------------------------
-    helper to build own formated string from given stringlist by
+    helper to build own formatted string from given stringlist by
     using given seperator
   ---------------------------------------------------------------*/
 ::rtl::OUString implc_convertStringlistToString( const ::com::sun::star::uno::Sequence< ::rtl::OUString >& lList     ,

Modified: openoffice/trunk/main/sfx2/source/dialog/filtergrouping.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/dialog/filtergrouping.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/dialog/partwnd.cxx (original)
+++ openoffice/trunk/main/sfx2/source/dialog/partwnd.cxx Sun May 22 01:05:14 2016
@@ -96,7 +96,7 @@ SfxPartChildWnd_Impl::~SfxPartChildWnd_I
 //        pWin->ReleaseChildWindow_Impl();
 /*
     // Release frame and window.
-    // If frame reference is valid here ... start dieing from inside by calling dispose().
+    // If frame reference is valid here ... start dying from inside by calling dispose().
     SetFrame( NULL );
     pWindow = NULL;
 */

Modified: openoffice/trunk/main/sfx2/source/doc/DocumentMetadataAccess.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/DocumentMetadataAccess.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/DocumentMetadataAccess.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/DocumentMetadataAccess.cxx Sun May 22 01:05:14 2016
@@ -817,7 +817,7 @@ DocumentMetadataAccess::DocumentMetadata
         const IXmlIdRegistrySupplier & i_rRegistrySupplier)
     : m_pImpl(new DocumentMetadataAccess_Impl(i_xContext, i_rRegistrySupplier))
 {
-    // no initalization: must call loadFrom...
+    // no initialization: must call loadFrom...
 }
 
 DocumentMetadataAccess::DocumentMetadataAccess(

Modified: openoffice/trunk/main/sfx2/source/doc/docfile.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/docfile.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/docfile.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/docfile.cxx Sun May 22 01:05:14 2016
@@ -318,7 +318,7 @@ public:
 	sal_Bool 		m_bRemoveBackup;
 	::rtl::OUString m_aBackupURL;
 
-	// the following member is changed and makes sence only during saving
+	// the following member is changed and makes sense only during saving
 	// TODO/LATER: in future the signature state should be controlled by the medium not by the document
 	//             in this case the member will hold this information
 	sal_uInt16		m_nSignatureState;
@@ -1203,7 +1203,7 @@ sal_Bool SfxMedium::LockOrigFileOnDemand
                             }
                             catch ( ucb::InteractiveIOException& e )
                             {
-                                // exception means that the lock file can not be successfuly accessed
+                                // exception means that the lock file can not be successfully accessed
                                 // in this case it should be ignored if system file locking is anyway active
                                 if ( bUseSystemLock || !IsOOoLockFileUsed() )
                                 {
@@ -1235,7 +1235,7 @@ sal_Bool SfxMedium::LockOrigFileOnDemand
                             }
                             catch ( uno::Exception& )
                             {
-                                // exception means that the lock file can not be successfuly accessed
+                                // exception means that the lock file can not be successfully accessed
                                 // in this case it should be ignored if system file locking is anyway active
                                 if ( bUseSystemLock || !IsOOoLockFileUsed() )
                                 {
@@ -1994,7 +1994,7 @@ void SfxMedium::Transfer_Impl()
 		aNameURL = pImp->pTempFile->GetURL();
 	else if ( aLogicName.Len() && pImp->m_bSalvageMode )
 	{
-		// makes sence only in case logic name is set
+		// makes sense only in case logic name is set
 		if ( !::utl::LocalFileHelper::ConvertPhysicalNameToURL( aName, aNameURL ) )
 			OSL_ENSURE( sal_False, "The medium name is not convertable!\n" );
 	}
@@ -2404,7 +2404,7 @@ void SfxMedium::GetLockingStream_Impl()
 
             if ( !pImp->pTempFile && !aName.Len() )
             {
-                // the medium is still based on the original file, it makes sence to initialize the streams
+                // the medium is still based on the original file, it makes sense to initialize the streams
                 if ( pImp->m_xLockingStream.is() )
                     pImp->xStream = pImp->m_xLockingStream;
 

Modified: openoffice/trunk/main/sfx2/source/doc/docvor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/docvor.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/docvor.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/docvor.cxx Sun May 22 01:05:14 2016
@@ -1649,7 +1649,7 @@ String SfxOrganizeDlg_Impl::GetPath_Impl
    [Return value]                 Empty sequence when users have clicked
                                   'Cancel', a sequence just containing one
                                   file name with path when they have
-                                  choosed one file or a sequence containing
+                                  chose one file or a sequence containing
                                   path and file names without path
 */
 

Modified: openoffice/trunk/main/sfx2/source/doc/objstor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/objstor.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/objstor.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/objstor.cxx Sun May 22 01:05:14 2016
@@ -1890,7 +1890,7 @@ sal_Bool SfxObjectShell::DisconnectStora
                 // contents, the storag will be broken
                 xOptStorage->attachToURL( aBackupURL, sal_True );
 
-                // the storage is successfuly attached to backup, thus it it owned by the document not by the medium
+                // the storage is successfully attached to backup, thus it it owned by the document not by the medium
                 rSrcMedium.CanDisposeStorage_Impl( sal_False );
                 bResult = sal_True;
             }
@@ -1932,7 +1932,7 @@ sal_Bool SfxObjectShell::ConnectTmpStora
             uno::Reference< embed::XOptimizedStorage > xOptStorage( xStorage, uno::UNO_QUERY_THROW );
             xOptStorage->writeAndAttachToStream( uno::Reference< io::XStream >() );
 
-            // the storage is successfuly disconnected from the original sources, thus the medium must not dispose it
+            // the storage is successfully disconnected from the original sources, thus the medium must not dispose it
             if ( pMediumArg )
                 pMediumArg->CanDisposeStorage_Impl( sal_False );
 
@@ -2672,7 +2672,7 @@ sal_Bool SfxObjectShell::DoSave_Impl( co
         SetError( GetMedium()->Unpack_Impl( pRetrMedium->GetPhysicalName() ), ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ) );
 */
 
-    // an interaction handler here can aquire only in case of GUI Saving
+    // an interaction handler here can acquire only in case of GUI Saving
     // and should be removed after the saving is done
     com::sun::star::uno::Reference< XInteractionHandler > xInteract;
     SFX_ITEMSET_ARG( pArgs, pxInteractionItem, SfxUnoAnyItem, SID_INTERACTIONHANDLER, sal_False );

Modified: openoffice/trunk/main/sfx2/source/doc/sfxbasemodel.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/sfxbasemodel.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/sfxbasemodel.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/sfxbasemodel.cxx Sun May 22 01:05:14 2016
@@ -1637,7 +1637,7 @@ void SAL_CALL SfxBaseModel::storeSelf( c
 			// stored in normal way.
 			if ( !hasLocation() || getLocation().compareToAscii( "private:", 8 ) == 0 )
 			{
-				// actually in this very rare case only UI parameters have sence
+				// actually in this very rare case only UI parameters have sense
 				// TODO/LATER: should be done later, after integration of sb19
                 bRet = m_pData->m_pObjectShell->DoSave()
                     && m_pData->m_pObjectShell->DoSaveCompleted();

Modified: openoffice/trunk/main/sfx2/source/view/frame.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/frame.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/frame.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/frame.cxx Sun May 22 01:05:14 2016
@@ -849,7 +849,7 @@ void SfxFrame::CreateWorkWindow_Impl()
 
 	if ( IsInPlace() )
 	{
-		// this makes sence only for inplace activated objects
+		// this makes sense only for inplace activated objects
 		try
 		{
 	    	Reference < XChild > xChild( GetCurrentDocument()->GetModel(), UNO_QUERY );

Modified: openoffice/trunk/main/sfx2/source/view/ipclient.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/ipclient.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/ipclient.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/ipclient.cxx Sun May 22 01:05:14 2016
@@ -999,7 +999,7 @@ ErrCode SfxInPlaceClient::DoVerb( long n
 				{
 					if ( nVerb == 0 || nVerb == embed::EmbedVerbs::MS_OLEVERB_OPEN )
 					{
-						// a workaround for the default verb, usually makes sence for alien objects
+						// a workaround for the default verb, usually makes sense for alien objects
 						try
 						{
 							m_pImp->m_xObject->doVerb( -9 ); // open own view, a workaround verb that is not visible
--- openoffice/trunk/main/reportdesign/source/core/misc/conditionalexpression.cxx (original)
+++ openoffice/trunk/main/reportdesign/source/core/misc/conditionalexpression.cxx Sun May 22 01:05:14 2016
@@ -99,16 +99,16 @@ namespace rptui
         sal_Int32 nLHSIndex( sMatchExpression.indexOf( sLHSPattern ) );
         sal_Int32 nRHSIndex( sMatchExpression.indexOf( sRHSPattern ) );
 
         // now we should have at most one occurance of $1 and $2, resp.
         OSL_ENSURE( sMatchExpression.indexOf( sLHSPattern, nLHSIndex + 1 ) == -1,
-            "ConditionalExpression::matchExpression: unsupported pattern (more than one LHS occurance)!" );
+            "ConditionalExpression::matchExpression: unsupported pattern (more than one LHS occurrence)!" );
         OSL_ENSURE( sMatchExpression.indexOf( sRHSPattern, nRHSIndex + 1 ) == -1,
-            "ConditionalExpression::matchExpression: unsupported pattern (more than one RHS occurance)!" );
+            "ConditionalExpression::matchExpression: unsupported pattern (more than one RHS occurrence)!" );
         // Also, an LHS must be present, and precede the RHS (if present)
         OSL_ENSURE( ( nLHSIndex != -1 ) && ( ( nLHSIndex < nRHSIndex ) || ( nRHSIndex == -1 ) ),
-            "ConditionalExpression::matchExpression: no LHS, or an RHS preceeding the LHS - this is not supported!" );
+            "ConditionalExpression::matchExpression: no LHS, or an RHS preceding the LHS - this is not supported!" );
 
         // up to the occurance of the LHS (which must exist, see above), the two expressions
         // must be identical
         if ( _rExpression.getLength() < nLHSIndex )
             return false;
@@ -118,7 +118,7 @@ namespace rptui
             // the left-most expression parts do not match
             return false;
 
         // after the occurance of the RHS (or the LHS, if there is no RHS), the two expressions
         // must be identical, too
         bool bHaveRHS( nRHSIndex != -1 );
         sal_Int32 nRightMostIndex( bHaveRHS ? nRHSIndex : nLHSIndex );
@@ -99,16 +99,16 @@ namespace rptui
         sal_Int32 nRHSIndex( sMatchExpression.indexOf( sRHSPattern ) );
 
-        // now we should have at most one occurance of $1 and $2, resp.
+        // now we should have at most one occurrence of $1 and $2, resp.
         OSL_ENSURE( sMatchExpression.indexOf( sLHSPattern, nLHSIndex + 1 ) == -1,
@@ -99,16 +99,16 @@ namespace rptui
 
-        // up to the occurance of the LHS (which must exist, see above), the two expressions
+        // up to the occurrence of the LHS (which must exist, see above), the two expressions
         // must be identical
         if ( _rExpression.getLength() < nLHSIndex )
@@ -118,7 +118,7 @@ namespace rptui
             return false;
 
-        // after the occurance of the RHS (or the LHS, if there is no RHS), the two expressions
+        // after the occurrence of the RHS (or the LHS, if there is no RHS), the two expressions
         // must be identical, too
         bool bHaveRHS( nRHSIndex != -1 );

Modified: openoffice/trunk/main/reportdesign/source/filter/xml/xmlfilter.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/reportdesign/source/filter/xml/xmlfilter.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/dialog/filtergrouping.cxx (original)
+++ openoffice/trunk/main/sfx2/source/dialog/filtergrouping.cxx Sun May 22 01:05:14 2016
@@ -114,7 +114,7 @@ namespace sfx2
 	the filter itself) nor indirectly (as part of another local group).</p>
 
 	<p>The only exception are filters which are part of a global class <em>and</em> a local class. This is allowed.
-	Beeing cotained in two local classes isn't.</p>
+	Being cotained in two local classes isn't.</p>
 
 	<p>So that's all what you need to know: Understand the concept of "filter classes" (a filter class combines
 	different filters and acts as if it's a filter itself) and the concept of groups (a group just describes a
@@ -441,7 +441,7 @@ namespace sfx2
 						||	( s_cWildcardSeparator == pBuffer[ nExistentWCEnd ] )
 						)
 					{	// it's really the complete wildcard we found
 						// (not something like _rWC beeing "*.t" and _rToBeExtended containing "*.txt")
 						// -> outta here
 						return;
 					}
@@ -441,7 +441,7 @@ namespace sfx2
 						)
 					{	// it's really the complete wildcard we found
-						// (not something like _rWC beeing "*.t" and _rToBeExtended containing "*.txt")
+						// (not something like _rWC being "*.t" and _rToBeExtended containing "*.txt")
 						// -> outta here
 						return;

Modified: openoffice/trunk/main/sfx2/source/dialog/partwnd.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/dialog/partwnd.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================